==> haskell-unicode-show-0.1.1.1-166.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unicode-show
version:              0.1.1.1
visibility:           public
id:                   unicode-show-0.1.1.1-3L8GbWUvRP13jwfCkWaN3L
key:                  unicode-show-0.1.1.1-3L8GbWUvRP13jwfCkWaN3L
license:              BSD-3-Clause
copyright:            2016 Takayuki Muranushi
maintainer:           igrep@n.email.ne.jp
author:               Takayuki Muranushi
homepage:             http://github.com/haskell-jp/unicode-show#readme
synopsis:             print and show in unicode
description:
    This package provides variants of '\''show'\'' and '\''print'\'' functions that does not escape non-ascii characters.

    See <http://github.com/haskell-jp/unicode-show#readme README> for usage.

    Run ghci with  @-interactive-print@ flag to print unicode characters. See <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/interactive-evaluation.html#ghci-interactive-print Using a custom interactive printing function> section in the GHC manual.

category:             Text
abi:                  27ced86d37af687b751f8ee47c4b8e55
exposed:              True
exposed-modules:      Text.Show.Unicode
import-dirs:          /usr/lib/ghc-9.6.6/site-local/unicode-show-0.1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/unicode-show-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/unicode-show-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unicode-show
hs-libraries:         HSunicode-show-0.1.1.1-3L8GbWUvRP13jwfCkWaN3L
depends:
    base-4.18.2.1 safe-0.3.21-6ywRAlXnRFuBscoqJeUz3o
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-unicode-show/html/unicode-show.haddock

haddock-html:         /usr/share/doc/haskell-unicode-show/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-show-0.1.1.1-167-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unicode-show
version:              0.1.1.1
visibility:           public
id:                   unicode-show-0.1.1.1-GAN5xIVqHOP5Q6a8z0hRG4
key:                  unicode-show-0.1.1.1-GAN5xIVqHOP5Q6a8z0hRG4
license:              BSD-3-Clause
copyright:            2016 Takayuki Muranushi
maintainer:           igrep@n.email.ne.jp
author:               Takayuki Muranushi
homepage:             http://github.com/haskell-jp/unicode-show#readme
synopsis:             print and show in unicode
description:
    This package provides variants of '\''show'\'' and '\''print'\'' functions that does not escape non-ascii characters.

    See <http://github.com/haskell-jp/unicode-show#readme README> for usage.

    Run ghci with  @-interactive-print@ flag to print unicode characters. See <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/interactive-evaluation.html#ghci-interactive-print Using a custom interactive printing function> section in the GHC manual.

category:             Text
abi:                  571557057e6407a4b65f3e97b5eb561e
exposed:              True
exposed-modules:      Text.Show.Unicode
import-dirs:          /usr/lib/ghc-9.6.6/site-local/unicode-show-0.1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/unicode-show-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/unicode-show-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unicode-show
hs-libraries:         HSunicode-show-0.1.1.1-GAN5xIVqHOP5Q6a8z0hRG4
depends:
    base-4.18.2.1 safe-0.3.21-7oQO4KcgDWt1YhK3ifcAwa
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-unicode-show/html/unicode-show.haddock

haddock-html:         /usr/share/doc/haskell-unicode-show/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
